==> gcc-4.1.1.tar.bz2: gcc-4.1.1/libjava/classpath/gnu/java/awt/peer/gtk/GtkCheckboxMenuItemPeer.java <==
/* GtkCheckboxMenuItemPeer.java -- Implements CheckboxMenuItemPeer with GTK+
   Copyright (C) 1999, 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package gnu.java.awt.peer.gtk;

import java.awt.CheckboxMenuItem;
import java.awt.ItemSelectable;
import java.awt.event.ItemEvent;
import java.awt.peer.CheckboxMenuItemPeer;

public class GtkCheckboxMenuItemPeer extends GtkMenuItemPeer
  implements CheckboxMenuItemPeer
{
  native void create (String label);

  public GtkCheckboxMenuItemPeer (CheckboxMenuItem menu)
  {
    super (menu);
    setState (menu.getState ());
  }

  public native void setState(boolean t);

  protected void postMenuActionEvent ()
  {
    CheckboxMenuItem item = (CheckboxMenuItem)awtWidget;
    q().postEvent (new ItemEvent ((ItemSelectable)awtWidget,
      ItemEvent.ITEM_STATE_CHANGED,
      item.getActionCommand(),
      item.getState() ? ItemEvent.DESELECTED : ItemEvent.SELECTED));

    super.postMenuActionEvent();
  }
}

==> gcc-4.4.1.tar.bz2: gcc-4.4.1/libjava/classpath/gnu/java/awt/peer/gtk/GtkCheckboxMenuItemPeer.java <==
/* GtkCheckboxMenuItemPeer.java -- Implements CheckboxMenuItemPeer with GTK+
   Copyright (C) 1999, 2005, 2006  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package gnu.java.awt.peer.gtk;

import java.awt.CheckboxMenuItem;
import java.awt.ItemSelectable;
import java.awt.event.ItemEvent;
import java.awt.peer.CheckboxMenuItemPeer;

public class GtkCheckboxMenuItemPeer extends GtkMenuItemPeer
  implements CheckboxMenuItemPeer
{
  protected native void create (String label);

  public GtkCheckboxMenuItemPeer (CheckboxMenuItem menu)
  {
    super (menu);
    setState (menu.getState ());
  }

  public native void setState(boolean t);

  /**
   * Called from the signal handler of the gtk widget.  Posts a
   * ItemEvent to indicate a state changed, then calls super to post
   * an ActionEvent.
   */
  protected void postMenuActionEvent ()
  {
    CheckboxMenuItem item = (CheckboxMenuItem)awtWidget;
    q().postEvent (new ItemEvent ((ItemSelectable)awtWidget,
      ItemEvent.ITEM_STATE_CHANGED,
      item.getActionCommand(),
      item.getState() ? ItemEvent.DESELECTED : ItemEvent.SELECTED));

    super.postMenuActionEvent();
  }
}
